set more off
clear 
set linesize 255
set pagesize 300
pause on

global remake_lp_mstr = 1		
global remake_eq_mstr = 1

global lpdir /san/Mortgages/Work/LoanPerformance/
global andrew /san/equifax/Work/equifax/samples/Andrew
global andrewdata /san/equifax/Work/equifax/samples/Andrew/HouseholdDebt/CreateData_and_Descriptives/data
global logs /san/equifax/Work/equifax/samples/Andrew/HouseholdDebt/CreateData_and_Descriptives/logs

local dir /san/equifax/Raw/equifax/RAWTEXT
local out /san/equifax/Work/equifax/samples/Andrew/HouseholdDebt/CreateData_and_Descriptives/data
*local nul /san/equifax/Work/equifax/samples/Andrew
local dictionary "$andrew/HouseholdDebt/CreateData_and_Descriptives/dct/eq_dct.dct"
local ciddictionary "$andrew/HouseholdDebt/CreateData_and_Descriptives/dct/cid_dct.dct"

log using $logs/1-pull_wholesample.log, replace

******************************************************************************
* 
*
* Calculating Homes Equity Losses for Equifax/LP Matched Sample
*
* Revised 7/16/12
* Output:
* 
* 
******************************************************************************

*** [1] Pull LP/EQ Key ***

* This section checks to make sure there are no dupes in the LP/EQ key and sorts the data.

use "$andrewdata/lpeq_key", clear 	 
	duplicates report cid			// 3,465,198 have no duplicates. Remainder have >=1 duplicate
	duplicates report loan_id		// no duplicate loan ids			
	sort deal_no loan_id
save "$andrewdata/lpeq_key.dta", replace
count
clear											
// n = 8,186,691.

*** [2] Merge Key with Current Static LP File ***

* This section merges the LP/EQ key with select variables from the LP static file, such as loan origination amount and home sale price

if $remake_lp_mstr == 1 {
   
   cd $lpdir/STATA/MSTR
   local mstrfiles : dir . files "??MSTR.dta"
   local mstrcount : word count `mstrfiles'
   disp `mstrcount'

   local mastervars deal_no loan_id close_bal fico exloan_id app_value under_rat1 under_rat2 loan_type occupancy orig_amt orig_date pmi_level state prop_type prop_zip purpose recourse sale_price document lien comb_ltv eff_ltv first_ltv second_ltv maturity ltv

   local i = 0
   foreach file of local mstrfiles {
      local ++i
      disp
      disp `"`file'"'
      use `mastervars' using `file', clear

      sort deal_no loan_id
      merge 1:1 deal_no loan_id using $andrewdata/lpeq_key.dta, update keep(master match match_update match_conflict)
          
      tempfile temp`i'
      save `temp`i''
   }

   use `temp1', clear
   forvalues i=2/`mstrcount' {
      append using `temp`i''
   }

   compress
   sort cid
   save $andrewdata/lp_mstr, replace
}						
tab _merge						// 12,910,952 in master only.
keep if _merge==3	
drop _merge
count
save "$andrewdata/lpkey", replace
// n = 7,064,092

bysort cid: gen n=_n					// Just pull the CIDs for the purpose of matching with the EQ records
keep if n==1
keep cid
count 
save "$andrewdata/lpkeycids", replace
clear
// n = 4,607,465

*** [3] Pull EQ Records ***

foreach qtr in "03" "06" "09" "12" {
	forval yr = 2002/2011 {
		** Set time stamp at start
		display "The current time and date is $S_TIME $S_DATE"
		** Collect local files:
		cd `dir'
		local filenames: dir "." files "rB8C3A14_FRB_`qtr'`yr'*.dat"
		local i = 1
		** Load each file in turn:
		foreach filename in `filenames' {
			** Load data:
			quietly infile using `dictionary', clear using (`filename')
			**Create time variable:
			gen date = "`qtr'`yr'"
			destring date, replace
			label var date "Quarter of data in format MYYYY"
			**Save data:
			compress
			save `out'/eq_pull_`qtr'`yr'`i', replace
			disp "***** Successfully Infiled and Saved `qtr'`yr' file# `i' `data' *****"
			scalar define max_i = `i'
			local i = `i' + 1
			}
		display "The current time and date is $S_TIME $S_DATE"
		drop _all
		** Append the ten (or eleven) component datasets for each tempf/quarter:
		local J = scalar(max_i)
		forval j = 1/`J' {
			append using "`out'/eq_pull_`qtr'`yr'`j'.dta"
			disp "*** Successfully appended `qtr_yr' file# `j' data ***"
			rm `out'/eq_pull_`qtr'`yr'`j'.dta
			disp "*** Successfully removed `qtr_yr' file# `j' from the server ***"
			}
		tab date, mi
		merge m:1 cid using "`out'/lpkeycids"
		tab _merge
		keep if _merge==3	
		save `out'/eq_pull_`qtr'`yr', replace
		}
	}
clear

if $remake_eq_mstr == 1 {
	cd "$andrewdata"
	local mstrfiles : dir . files "eq_pull_03*.dta"
	local mstrcount : word count `mstrfiles'
	disp `mstrcount'

local i = 0
   foreach file of local mstrfiles {
      local ++i
      disp
      disp `"`file'"'
      use `file', clear
      drop _merge

      tempfile temp`i'
      save `temp`i'', replace
   }
   use `temp1', clear
   forvalues i=2/`mstrcount' {
      append using `temp`i''
   }

}
compress
count
save "$andrewdata/q3sample.dta", replace	
clear

if $remake_eq_mstr == 1 {
	cd "$andrewdata"
	local mstrfiles : dir . files "eq_pull_06*.dta"
	local mstrcount : word count `mstrfiles'
	disp `mstrcount'

local i = 0
   foreach file of local mstrfiles {
      local ++i
      disp
      disp `"`file'"'
      use `file', clear
      drop _merge

      tempfile temp`i'
      save `temp`i'', replace
   }
   use `temp1', clear
   forvalues i=2/`mstrcount' {
      append using `temp`i''
   }

}
compress
count
save "$andrewdata/q6sample.dta", replace	
clear

if $remake_eq_mstr == 1 {
	cd "$andrewdata"
	local mstrfiles : dir . files "eq_pull_09*.dta"
	local mstrcount : word count `mstrfiles'
	disp `mstrcount'

local i = 0
   foreach file of local mstrfiles {
      local ++i
      disp
      disp `"`file'"'
      use `file', clear
      drop _merge

      tempfile temp`i'
      save `temp`i'', replace
   }
   use `temp1', clear
   forvalues i=2/`mstrcount' {
      append using `temp`i''
   }

}
compress
count
save "$andrewdata/q9sample.dta", replace	
clear

if $remake_eq_mstr == 1 {
	cd "$andrewdata"
	local mstrfiles : dir . files "eq_pull_12*.dta"
	local mstrcount : word count `mstrfiles'
	disp `mstrcount'

local i = 0
   foreach file of local mstrfiles {
      local ++i
      disp
      disp `"`file'"'
      use `file', clear
      drop _merge

      tempfile temp`i'
      save `temp`i'', replace
   }
   use `temp1', clear
   forvalues i=2/`mstrcount' {
      append using `temp`i''
   }

}
compress
count
save "$andrewdata/q12sample.dta", replace	
clear
	
// whole sample has n = 68,339,109; 3,792,514 individual CIDs. 

log close
clear
exit
