
set more off
clear 
set linesize 255
set pagesize 300
pause on

global remake_lp_mstr = 1		
global remake_eq_mstr = 1

global andrew /san/equifax/Work/equifax/samples/Andrew
global andrewdata /san/equifax/Work/equifax/samples/Andrew/HouseholdDebt/CreateData_and_Descriptives/data
global logs /san/equifax/Work/equifax/samples/Andrew/HouseholdDebt/CreateData_and_Descriptives/logs

local dir /san/equifax/Raw/equifax/RAWTEXT
local out /san/equifax/Work/equifax/samples/Andrew/HouseholdDebt/CreateData_and_Descriptives/data
*local nul /san/equifax/Work/equifax/samples/Andrew
local dictionary "$andrew/HouseholdDebt/CreateData_and_Descriptives/dct/eq_dct.dct"
local ciddictionary "$andrew/HouseholdDebt/CreateData_and_Descriptives/dct/cid_dct.dct"

log using $logs/2-filter_sample_lastloan.log, replace

*** [3] Restrict to Primary Sample ***

foreach qtr in "3" "6" "9" "12" {
use "$andrewdata/q`qtr'sample.dta" if flag=="P", clear
save "$andrewdata/qprimary`qtr'.dta", replace
}

if $remake_eq_mstr == 1 {
	cd "$andrewdata"
	local mstrfiles : dir . files "qprimary*.dta"
	local mstrcount : word count `mstrfiles'
	disp `mstrcount'

local i = 0
   foreach file of local mstrfiles {
      local ++i
      disp
      disp `"`file'"'
      use `file', clear

      tempfile temp`i'
      save `temp`i''
   }
   use `temp1', clear
   forvalues i=2/`mstrcount' {
      append using `temp`i''
   }

}
compress
count
save "$andrewdata/primarysample.dta", replace	
clear
// n = []; [] unique CIDs in the primary sample.

*** [4] Restrict Sample Based on Loan and Match Characteristics ***

* This section filters the LP/EQ key for only loans that meet certain criteria and filters the EQ primary sample 
use "$andrewdata/lpkey", clear
drop if conf<=0.75				// Low confidence level: 393,669 loans dropped
drop if lien~="1"				// Only first liens: 1,125,246 loans dropped
gen origy=substr(orig_date,1,4)
destring origy, gen(oy)
drop if oy<2002|oy>2006				// Only originations 2002-06: 968,013 loans dropped
drop if purpose=="4"|purpose=="Z"		// Drop second mortgage and home improvement/debt consolidation/education loans: 291 loans dropped

gen LPy=substr(orig_date,-8,4)			// Keep only last LP loan
gen LPm=substr(orig_date,-4,2)
gen LPd=substr(orig_date,-2,2)
destring LPy LPm LPd, replace
gen origin_date=mdy(LPm,LPd,LPy)
drop LPy LPm LPd orig_date 
sort cid origin_date
by cid: gen n=_n
by cid: egen maxn=max(n)
count if n==1
keep if maxn==n
count
keep prop_zip origin_date orig_amt sale_price app_value cid	purpose loan_type document // delete unecessary variables
save "$andrewdata/temp.dta", replace				// n = 3,369,523

keep cid
merge 1:m cid using "$andrewdata/primarysample.dta"
tab _merge
keep if _merge==3
bysort cid: gen n=_n
count if n==1							// 458,303 individuals
drop _merge n

tostring date, gen(x)						// create new date variables for each quarter of EQ
gen y2=substr(x,-4,4)
gen m2=substr(x,-6,2) if substr(x,-6,1)=="1"
replace m2=substr(x,-5,1) if (substr(x,-5,1)=="3"|substr(x,-5,1)=="6"|substr(x,-5,1)=="9")
destring y2, gen(EQy)
destring m2, gen(EQm)
gen q=1 if EQm==3
replace q=2 if EQm==6
replace q=3 if EQm==9
replace q=4 if EQm==12
gen quarter=yq(EQy,q)
drop y2 m2 x q

// Delete people with >1 mortgage for more than 2 consecutive quarters unless one is a secondary mortgage
local m=1						
	while `m'<15{
		gen m`m'=0
		gen primary`m'=1
		gen pm`m'=0
		local m=`m'+1
	}

local v=3
local p1=9
local p2=10
local m2=1
	while `v'<159 {
		replace m`m2'=1 if cust_attr`v'~=0
		* Using Donghoon's code, reclassify home improvement, second mortgage, home equity, secured credit line, line of credit
		replace primary`m2'=0 if (cust_attr`p1'==121|cust_attr`p1'==153|cust_attr`p1'==226|cust_attr`p1'==54|cust_attr`p1'==73|cust_attr`p2'==121|cust_attr`p2'==153|cust_attr`p2'==226|cust_attr`p2'==54|cust_attr`p2'==73)
		replace pm`m2'=m`m2'*primary`m2'
		local v=`v'+12
		local p1=`p1'+12
		local p2=`p2'+12
		local m2=`m2'+1
		}

gen pms=pm1+pm2+pm3+pm4+pm5+pm6+pm7+pm8+pm9+pm10+pm11+pm12+pm13+pm14	// primary mortgages in a given quarter
gen moreone=(pms>1)
egen id=group(cid)
bysort id quarter: gen n=_n
	tab n
	drop if n>1							// 2,722 duplicate ID/equarter observations
xtset id quarter
by id: gen consecmoreone=sum(moreone)*moreone
by id: egen maxconsec=max(consecmoreone)
drop if maxconsec>2	 	// drop if have two non-secondary mortgages for more than 2 consecutive quarters
drop m2 primary2 m3 primary3 m4 primary4 m5 primary5 m6 primary6 m7 primary7 m8 primary8 m9 primary9 m10 primary10 m11 primary11 m12 primary12 m13 primary13 m14 primary14 moreone consecmoreone maxconsec

save "$andrewdata/primarysamplefiltered.dta", replace
// n = 12,365,341; 316,417 unique CIDs.

*** [5] Merge LP Loans With EQ Primary Panel ***

keep cid			// identify loans in match key that are in primarysamplefiltered
bysort cid: gen n=_n
keep if n==1
merge 1:m cid using "$andrewdata/temp.dta"
keep if _merge==3
drop _merge n

sort cid origin_date
by cid: gen loanno=_n
* Put data in wide format, so all loans can be merged to each observation in EQ; it appears easier to match LP loans to EQ mortages this way.
reshape wide app_value orig_amt origin_date prop_zip sale_price loan_type document, i(cid) j(loanno)	
save "$andrewdata/lpkey_static", replace		// n = 455,937

merge 1:m cid using "$andrewdata/primarysamplefiltered.dta"
drop _merge 
drop n
bysort cid: gen n=_n
count if n==1
drop n
save "$andrewdata/primarysamplefilteredwLP-lastloan.dta", replace
// n = 12,365,341; 316,417 unique CIDs.
clear
log close
