set more off
clear 
set linesize 255
set pagesize 300
set varabbrev off
pause on

global remake_lp_mstr = 1		
global remake_eq_mstr = 1

global andrew /san/equifax/Work/equifax/samples/Andrew
global andrewdata /san/equifax/Work/equifax/samples/Andrew/HouseholdDebt/CreateData_and_Descriptives/data
global logs /san/equifax/Work/equifax/samples/Andrew/HouseholdDebt/CreateData_and_Descriptives/logs

local dir /san/equifax/Raw/equifax/RAWTEXT
local out /san/equifax/Work/equifax/samples/Andrew/HouseholdDebt/CreateData_and_Descriptives/data
*local nul /san/equifax/Work/equifax/samples/Andrew

log using $logs/3a-equitytrack_lastloan.log, replace

*** [1] Matching the LP Loans to the EQ Mortgage ***

** n.b. this program is written for the general case in which we match up to 26 LP loans to 14 equifax 
** mortgages, but the parameters have been set to the case of only one LP loan 


use "$andrewdata/primarysamplefilteredwLP-lastloan.dta"
// n = 12,365,341; 316,417 unique CIDs.

sort id quarter
xtset id quarter

** Change EQ mortgage origination date to date variables so they can be matched	to LP loans **
local i=2
	while `i'<159 {
		gen temp`i'=(cust_attr`i'<100000)		
		tostring cust_attr`i', replace
		gen y`i'=substr(cust_attr`i',-4,4) if cust_attr`i'~="0"
		gen m`i'=substr(cust_attr`i',-5,1) if temp`i'==1 & cust_attr`i'~="0"
		replace m`i'=substr(cust_attr`i',-6,2) if temp`i'==0 & cust_attr`i'~="0"
		replace m`i'="0" if m`i'==""
		replace y`i'="0" if y`i'==""
		destring m`i' y`i', replace
		gen o`i'=1
		gen cust_attr`i'date=mdy(m`i',o`i',y`i') if m`i'~=0 & y`i'~=0
		drop cust_attr`i'
		drop temp`i' m`i' y`i' o`i'
		format cust_attr`i'date %d 
		local i=`i'+12
		}
local j=1
	while `j'<=1 {
		format origin_date`j' %d
		local j=`j'+1
	}

** Generate 364 indicators in each quarter if EQ mortgage `t' matches to LP loan `k' **	
** match is based on being within 6 months of origination date, 15 percent of the origination amount, and the EQ mortage
** being a primary mortgage (using the pm`k' variable)

// rename indicators identifying primary mortgages
local j=1						
local j2=2
	while `j'<15 {
		rename pm`j' primary`j2'
		label var primary`j2' "EQ Mortgage #`j' is Primary"
		local j=`j'+1
		local j2=`j2'+12
	}

**** note need to change number of lp loans from 3 to 26 ***
// create indicator variables for whether EQ mortgage `t' matches with LP loan `k'
local t=2				
local t2=3
local m=1
	while `t'<159 {
		local k=1
		while `k'<=1 {
			gen match`t'to`k'=(cust_attr`t'date>origin_date`k'-180 & cust_attr`t'date<origin_date`k'+180) & (cust_attr`t2'>orig_amt`k'*0.85 & cust_attr`t2'<orig_amt`k'*1.15) & primary`t'==1
			label var match`t'to`k' "EQ Mortgage #`m' Match to LP Loan #`k'"		
			local k=`k'+1
		}
		local t=`t'+12
		local t2=`t2'+12
		local m=`m'+1
	}

gen n=_n
save "$andrewdata/temp.dta", replace

*** [2] Merge Zillow Indices (on zip code and quarter) ***

keep prop_zip* quarter n
save "$andrewdata/temp2.dta", replace
clear

insheet using "$andrewdata/Zip_Zhvi_AllHomes_2011-07_ZIPcorrected.csv", comma	// rename and format merge variables		
	rename regionname prop_zip
	tostring prop_zip, format(%05.0f) replace			
	drop sizerank msa city state regionid v1996* v1997* v1998* v1999* v2000* v2001* *01 *02 *04 *05 *07 *08 *10 *11 
	reshape long v, i(prop_zip) j(date)
	gen x=string(date)
	gen year=substr(x,1,4)
	gen month=substr(x,5,2) if substr(x,5,1)=="1"
	replace month=substr(x,6,1) if substr(x,5,1)=="0"
	destring month, replace
	destring year, replace
	gen q=1 if month==3
	replace q=2 if month==6
	replace q=3 if month==9
	replace q=4 if month==12
	gen quarter=yq(year,q)
	keep quarter v prop_zip
save "$andrewdata/indices.dta", replace	
// 9,909 zip codes covered 

local t=1				// merge zip codes for each LP loan
	while `t'<=1 {
		use "$andrewdata/indices.dta", clear
		rename prop_zip prop_zip`t'
		rename v v`t'
		label var v`t' "LP Loan #`t' Index"
		merge 1:m prop_zip`t' quarter using "$andrewdata/temp2.dta"
		drop if _merge==1
		drop _merge
		save "$andrewdata/temp2.dta", replace
		local t=`t'+1
		}
keep n v*
merge 1:1 n using "$andrewdata/temp.dta"
drop _merge n

*** [3] Calculate Home Values and Equity Over Time *** 

// Identify EQ quarter when home was bought with LP loan `t' and value of home after purchased with LP loan `t';
// Identify the EQ mortgage corresponding to that loan

sort id quarter 
by id: gen period=_n
local t=1						
	while `t'<=1 {
		gen matches`t'=match2to`t'+match14to`t'+match26to`t'+match38to`t'+match50to`t'+match62to`t'+match74to`t'+match86to`t'+match98to`t'+match110to`t'+match122to`t'+match134to`t'+match146to`t'+match158to`t'
			label var matches`t' "Number of EQ Mortgages Matched to LP Loan #`t'"
		gen anymatch`t'=(match2to`t'+match14to`t'+match26to`t'+match38to`t'+match50to`t'+match62to`t'+match74to`t'+match86to`t'+match98to`t'+match110to`t'+match122to`t'+match134to`t'+match146to`t'+match158to`t'>0)
			label var anymatch`t' "Match of Any EQ Mortgages to LP Loan #`t'"
		by id: gen owned`t'=sum(anymatch`t') 					
			gen x`t'=owned`t'*period		
				replace x`t'=. if x`t'==0
			by id: egen y`t'=min(x`t')
			gen firstmatch`t'=(x`t'==y`t') & x`t'~=.	
				label var firstmatch`t' "First Match of Any EQ Mortgages to LP Loan #`t'"
			by id: gen bought`t'=sum(firstmatch`t')	
				label var bought`t' "Home Has Been Bought with LP Loan #`t'"	// = 1 for period of origination and every thereafter
		gen orig_value`t'=sale_price`t'
			replace orig_value`t'=app_value`t' if orig_value`t'==0
			label var orig_value`t' "Purchase Value of Home Bought With LP Loan #`t'"
		gen temp`t'=v`t' if firstmatch`t'==1
			replace temp`t'=0 if temp`t'==.
			by id: egen orig_index`t'=max(temp`t')
		gen value`t'=orig_value`t'*(1+(v`t'-orig_index`t')/orig_index`t') if bought`t'==1
			label var value`t' "Current Value of Home Bought With LP Loan #`t'"
		* consider being more precised about origination index; I've assume it's the index in the first quarter it appears	
		gen orig_eqdate_LP`t'=cust_attr2date if firstmatch`t'==1 & match2to`t'==1
			local r=14
				while `r'<159 {
				replace orig_eqdate_LP`t'=cust_attr`r'date if firstmatch`t'==1 & match`r'to`t'==1
				local r=`r'+12
				}
			by id: egen orig_eqdate2_LP`t'=max(orig_eqdate_LP`t')
			drop orig_eqdate_LP`t'
			rename orig_eqdate2_LP`t' orig_eqdate_LP`t'
			format orig_eqdate_LP`t' %d
			label var orig_eqdate_LP`t' "Opening Date of EQ Mortgage First Matched to LP Loan #`t'"
		gen orig_eqamt_LP`t'=firstmatch`t'*(cust_attr3*match2to`t'+cust_attr15*match14to`t'+cust_attr27*match26to`t'+cust_attr39*match38to`t'+cust_attr51*match50to`t'+cust_attr63*match62to`t'+cust_attr75*match74to`t'+cust_attr87*match86to`t'+cust_attr99*match98to`t'+cust_attr111*match110to`t'+cust_attr123*match122to`t'+cust_attr135*match134to`t'+cust_attr147*match146to`t'+cust_attr159*match158to`t')
			by id: egen orig_eqamt2_LP`t'=max(orig_eqamt_LP`t')
			drop orig_eqamt_LP`t'
			rename orig_eqamt2_LP`t' orig_eqamt_LP`t'
			label var orig_eqamt_LP`t' "Opening Balance of EQ Mortgage First Matched to LP Loan #`t'"
		local t=`t'+1
	}

// Identify if mortgage corresponding to LP loan is still outstanding (track equity for as long as outstanding)
local k=1
while `k'<=1 {
	local t=2
	while `t'<=158 {
		gen lp`k'outstandingeq`t'=(cust_attr`t'date==orig_eqdate_LP`k' & primary`t'==1)
		label var lp`k'outstandingeq`t' "EQ Mortgage #`t' is Same as First Matched to LP Loan #`k'"
		local t=`t'+12
	}
	gen lp`k'outstanding=bought1*(lp`k'outstandingeq2+lp`k'outstandingeq14+lp`k'outstandingeq26+lp`k'outstandingeq38+lp`k'outstandingeq50+lp`k'outstandingeq62+lp`k'outstandingeq74+lp`k'outstandingeq86+lp`k'outstandingeq98+lp`k'outstandingeq110+lp`k'outstandingeq122+lp`k'outstandingeq134+lp`k'outstandingeq146+lp`k'outstandingeq158)
	label var lp`k'outstanding "Loan #`k' is Still Outstanding"
	local k=`k'+1
}

// Calculate equity in home as value minus EQ primary mortgage matched to LP loan, non-primary mortgages, and home equity loans
local k=1
while `k'<=1 {
	gen homedebt`k'=cust_attr3*lp`k'outstandingeq2+cust_attr15*lp`k'outstandingeq14+cust_attr27*lp`k'outstandingeq26+cust_attr39*lp`k'outstandingeq38+cust_attr51*lp`k'outstandingeq50+cust_attr63*lp`k'outstandingeq62+cust_attr75*lp`k'outstandingeq74+cust_attr87*lp`k'outstandingeq86+cust_attr99*lp`k'outstandingeq98+cust_attr111*lp`k'outstandingeq110+cust_attr123*lp`k'outstandingeq122+cust_attr135*lp`k'outstandingeq134+cust_attr147*lp`k'outstandingeq146+cust_attr159*lp`k'outstandingeq158
	label var homedebt`k' "Balance on Purchase Mortgage for LP Loan #`k'"
	gen seconddebt`k'=cust_attr3*(1-primary2)+cust_attr15*(1-primary14)+cust_attr27*(1-primary26)+cust_attr39*(1-primary38)+cust_attr51*(1-primary50)+cust_attr63*(1-primary62)+cust_attr75*(1-primary74)+cust_attr87*(1-primary86)+cust_attr99*(1-primary98)+cust_attr111*(1-primary110)+cust_attr123*(1-primary122)+cust_attr135*(1-primary134)+cust_attr147*(1-primary146)+cust_attr159*(1-primary158)
	label var seconddebt`k' "Secondary Mortgage Balance for LP Loan #`k'"
	gen equitydebt`k'=crtr_attr172+crtr_attr173
		replace equitydebt`k'=0 if equitydebt`k'==.
	label var equitydebt`k' "Home Equity Balance for LP Loan #`k'"
	gen equity`k'=lp`k'outstanding*(value`k'-homedebt`k'-seconddebt`k'-equitydebt`k')
	label var equity`k' "Equity for LP Loan #`k'"
	local k=`k'+1
	}
	
// Clean up dataset
label var quarter "Quarter (time series variable)"	
label var period "Number of Quarter in Individual Time Series"	
local j=2						
	while `j'<=158 {
		rename cust_attr`j'date cust_attr`j'
		label var cust_attr`j' "Opening Date of EQ Mortgage #`j'"
		local j=`j'+12
		}
save "$andrewdata/working-lastloan.dta", replace

log close

clear
exit

