set more off
capture log close
clear 
set linesize 255
set pagesize 300
set varabbrev off
set matsize 11000
pause on

global andrew /san/Equifax/Work/equifax/samples/Andrew/HouseholdDebt/CreateData_and_Descriptives
global andrewdata $andrew/data
global logs $andrew/logs
local timetoforecl "/san/Equifax/Work/equifax/samples/Andrew/HouseholdDebt/TimeToForeclosure/data"
adopath + /san/Equifax/Work/equifax/samples/Andrew/ado
global email brandi.coates@ny.frb.org
log using $logs/4-finaldataprep.log, replace t		


*************************************************
*** Final Preparation of Data Before Analysis ***
*************************************************

* Before calling in Equifax Dataset, prep data containing zip, cnty, MSA, state info for merging later
use "$andrewdata/zip_to_county.dta", clear
desc, full
rename zipcode 	zip
rename state 	lpstate
rename msa lpmsa
rename CBSA lpcbsa
gen lpstatefips=substr(ansi, 1, 2)
gen lpcountyfips=substr(ansi, 3, .)
destring lpstatefips lpcountyfips, replace
drop ansi
	lab var	lpstate			"State where property located."
	lab var	lpmsa			"MSA where property located."
	lab var	lpcbsa			"CBSA where property located."
	lab var lpstatefips 	"State FIPS where property located."
	lab var lpcountyfips	"County FIPS where property located."
bysort zip: assert _n==1	//Every zip in file occurs atmost once.
tempfile lpzip_state
save `lpzip_state'


use "$andrewdata/zip_to_county.dta", clear
rename msa eqmsa
rename CBSA eqcbsa
gen eqstatefips=substr(ansi, 1, 2)
gen eqcountyfips=substr(ansi, 3, .)
destring eqstatefips eqcountyfips, replace
drop ansi state
	lab var	eqmsa			"MSA where individual lives."
	lab var	eqcbsa			"CBSA where individual lives."
	lab var eqstatefips 	"State FIPS where individ lives."
	lab var eqcountyfips	"County FIPS where individ lives."
bysort zipcode: assert _n==1	//Every zip in file occurs atmost once.
tempfile eqzip_state
save `eqzip_state'

* ---- Prep LP data estimating Time to Foreclosure (Duration to REO) for merging later ---- *
tempfile year_duration_to_REO
tempfile quarter_duration_to_REO

foreach time in year quarter {
	*use `timetoforecl'/`time'_county_level_REO_distribution_20_Nov5_2013, clear  	//created in Duration_to_REO_20.do
											//time locals are annual quarterly
	use "`timetoforecl'/REO_county_`time'_20", clear
	noi disp "Using REO_county_`time'_20"
	drop if county==""
	destring county, replace force	//6 obs should be replaced with missing
	save ``time'_duration_to_REO'
	noi disp " `time' tempfile resolves to ``time'_duration_to_REO'."
}

*---------------------- Call in main dataset. -----------------------------*
use "$andrewdata/working-lastloan.dta", clear	

* We often change the denominator - looking for a proxy for income or wealth.
global denominator "orig_value1"
desc $denominator, full

* Merge in MSAs for property and individual location
keep if bought1==1 & lp1outstanding==1		// start tracking people when they take out the LP loan as long as LP loan is outstanding and can track equity
drop if value1==.				//	Drop people when no measure of home value

rename prop_zip1 zip
label var zip "Prop zip from LP dataset."
drop if substr(zip,1,2)=="00"			// 2690 dropped. Zips below 01000 are in Puerto Rico or special IRS codes with no HPI. 
replace zipcode=. if zipcode<1000
gen zipcode2=string(zipcode,"%05.0f")
drop zipcode
rename zipcode2 zipcode
merge m:1 zip using `lpzip_state'		// get MSA data for property location and individual location.	
drop if _merge==2
drop _merge
merge m:1 zipcode using `eqzip_state'
drop if _merge==2
drop _merge
rename state eqstate
rename v1 hpi

if 0==0 {	// Create variables
sort id quarter 
xtset id quarter

*-----------------------------------------------------------------*
*-----------------DATA: CREATE NEW VARIABLES----------------------*
*-----------------------------------------------------------------*

*a)	primary mortgage - homedebt
	rename homedebt1 homedebt
	gen lnlaghomedebt = ln(l.homedebt)	//ln(lagged mortg bal) added to regs to give scale.
*b)	other mortgage (2nd mortgage, home equity installment) - othermortgage 
	egen othermortgage=rsum(seconddebt1 crtr_attr172)
*c)	helocs - helocs
	replace crtr_attr173=0 if crtr_attr173==.
	gen helocs=crtr_attr173
*d)	credit cards (bank cards, consumer finance, retail trades, other trades) - ccdebt
	*egen ccdebt=rsum(crtr_attr169 crtr_attr170 crtr_attr174 crtr_attr176)
	*egen ccdebt=rsum(crtr_attr169 crtr_attr170 crtr_attr174)
	gen ccdebt=crtr_attr169
*-) other debt
	replace crtr_attr174=0 if crtr_attr174==.
	gen otherdebt = crtr_attr174
*e)	auto (auto, auto bank) - autodebt
	egen autodebt=rsum(crtr_attr167 crtr_attr168)
*f)	student - studdebt 
	replace crtr_attr175=0 if crtr_attr175==.	
	gen studdebt=crtr_attr175 
*g)	Total non-housing (exclude mortgages and helocs) - allnonhouse
	replace crtr_attr166=0 if crtr_attr166==.	
	gen allnonhouse=max(crtr_attr166-homedebt-othermortgage-helocs,0)
*h)	Total non-mortgage (include helocs) - allnonmortgage
	gen allnonmortgage=max(crtr_attr166-homedebt-othermortgage,0)
*i)	Total excluding primary mortgage - allnonhomedebt 
	gen allnonhomedebt=max(crtr_attr166-homedebt,0)
*j)	Total including everything - alldebt
	gen alldebt=crtr_attr166 
*m)	Generate dummies for decade of birth
	gen age=EQy-cust_attr1
	gen agecat=1 if age<=25
		replace agecat=2 if age>25 & age<=35
                replace agecat=3 if age>35 & age<=45
                replace agecat=4 if age>45 & age<=55
                replace agecat=5 if age>55 & age<=65
                replace agecat=6 if age>65 & age<.
*n)	Generate indicators for FICO score
	gen risk_cat=9 if riskscore>=750 & riskscore<.
                replace risk_cat=8 if riskscore>=720 & riskscore<750
                replace risk_cat=7 if riskscore>=680 & riskscore<720
                replace risk_cat=6 if riskscore>=650 & riskscore<680
                replace risk_cat=5 if riskscore>=620 & riskscore<650
                replace risk_cat=4 if riskscore>=590 & riskscore<620
                replace risk_cat=3 if riskscore>=560 & riskscore<590
                replace risk_cat=2 if riskscore>=530 & riskscore<560
                replace risk_cat=1 if riskscore<530
	gen lrisk_cat = l.risk_cat		//risk cat lagged by 1 qtr
*o) 	Year dummy variables; date = Quarter of data in format MYYYY
	tab EQy
	summarize EQy
		local yearmin=`r(min)'
		local yearmax=`r(max)'
	forvalues x=`yearmin'/`yearmax' {
		gen year_`x'=(EQy==`x')
		}
*t)	Replace missing to zeroes
	forval i=12/154 {
		quietly replace crtr_attr`i'=0 if crtr_attr`i'==.
		}
	forvalues i=166/187 {
		replace crtr_attr`i'=0 if crtr_attr`i'==.
		}
*u)	Indicators and amount of consumer finance, bankcard, retail, or other trades more than 60dpd
	/*
	gen ccdebt_60dpd =(crtr_attr35>0|crtr_attr36>0|crtr_attr37>0|crtr_attr38>0|crtr_attr42>0|crtr_attr43>0|crtr_attr44>0|crtr_attr45>0|crtr_attr70>0|crtr_attr71>0|crtr_attr72>0|crtr_attr73>0|crtr_attr84>0|crtr_attr85>0|crtr_attr86>0|crtr_attr87>0) 
	gen ccdebt_90dpd =(crtr_attr36>0|crtr_attr37>0|crtr_attr38>0|crtr_attr43>0|crtr_attr44>0|crtr_attr45>0|crtr_attr71>0|crtr_attr72>0|crtr_attr73>0|crtr_attr85>0|crtr_attr86>0|crtr_attr87>0) 
	gen ccdebt_60dpd_amt = (crtr_attr109 + crtr_attr110 +crtr_attr111 +crtr_attr112 + crtr_attr115 + crtr_attr116 + crtr_attr117 + crtr_attr118 + crtr_attr139 + crtr_attr140 + crtr_attr141 + crtr_attr142 + crtr_attr151 + crtr_attr152 + crtr_attr153+ crtr_attr154) 
		replace ccdebt_60dpd_amt = 0 if ccdebt_60dpd==0
	*/
	gen ccdebt_60dpd =(crtr_attr35>0|crtr_attr36>0|crtr_attr37>0|crtr_attr38>0) 
	gen ccdebt_90dpd =(crtr_attr36>0|crtr_attr37>0|crtr_attr38>0) 
	gen ccdebt_60dpd_amt = (crtr_attr109 + crtr_attr110 +crtr_attr111 +crtr_attr112) 
		replace ccdebt_60dpd_amt = 0 if ccdebt_60dpd==0
		
	*Lagged variable of delinquent cc debt generated in another loop below. See "Generate lagged variables to be used in regs"

*v)	Indicators and amount of autodebt more than 60dpd
	gen autodebt_60dpd = (crtr_attr21>0|crtr_attr22>0|crtr_attr23>0|crtr_attr24>0|crtr_attr28>0|crtr_attr29>0|crtr_attr30>0|crtr_attr31>0) 
	gen autodebt_90dpd = (crtr_attr22>0|crtr_attr23>0|crtr_attr24>0|crtr_attr29>0|crtr_attr30>0|crtr_attr31>0) 
	gen autodebt_60dpd_amt = (crtr_attr97 + crtr_attr98 + crtr_attr99 + crtr_attr100 + crtr_attr103 + crtr_attr104 + crtr_attr105 + crtr_attr106)
		
		replace autodebt_90dpd=0 if autodebt==0	//set autodebt to zero if no auto acct
		replace autodebt_60dpd_amt = 0 if autodebt_60dpd==0
		
*aa)	Number of bankcard or department store accounts
	*egen ccaccounts=rsum(cma_attr3102 cma_attr3104)
	*lab var ccaccounts	"No. bankcard and dept store accts"
	
	gen ccaccounts=cma_attr3102
	lab var ccaccounts	"No. bankcard and dept store accts"
	
*ad)	Indicators of helocs more than 60dpd
	gen helocs_60dpd =(crtr_attr133>0|crtr_attr134>0|crtr_attr135>0|crtr_attr136>0) 
	gen helocs_90dpd =(crtr_attr134>0|crtr_attr135>0|crtr_attr136>0) 
		replace helocs_90dpd=. if helocs==0 //Set helocs_90dpd to missing if no heloc account
		
*ae)	Indicators of mortgage, installment loans more than 60dpd
	gen mortgage_60dpd=(crtr_attr121>0|crtr_attr122>0|crtr_attr123>0|crtr_attr124>0)
	gen mortgage_90dpd=(crtr_attr122>0|crtr_attr123>0|crtr_attr124>0)
	gen heloan_60dpd=(crtr_attr127>0|crtr_attr128>0|crtr_attr129>0|crtr_attr130>0)
	gen heloan_90dpd=(crtr_attr128>0|crtr_attr129>0|crtr_attr130>0)

* Indicate whether property in NonRecourse State or a State where Foreclosures must go through the courts.
* Do so based on prop zipcode from LP dataset (zip), not zipcode where person lives (Equifax var zipcode)
*ag)	NonRecourse States according to Ghent and Kudlyak Definitions: 
	/* When a lender forecloses on a mortgage, the debt often exceeds the amount that the lender recovers through the foreclosure sale.
	In states classified as "non-recourse," the lender cannot seek a judgment against the debtor to recover the deficiency. 
	"Recourse" states allow lenders to seek a deficiency judgment against the debtor. */
	gen recourse=1
	replace recourse=0 if (inlist(lpstate, "AK", "AZ", "CA", "IA", "MN") | inlist(lpstate, "MT", "NC", "ND", "OR", "WA", "WI"))
	
	*Recode Refis in CA, MT, and NC as recourse as done in Ghent Kudlyak
	tab purpose, missing									// (1)Purchase (2)Refi,Cash Out (3)Refi, No Cash Out (5)Refi,Unknown Cash
	*replace recourse=1 if purpose=="2"						// code as recourse if cash out refi
	replace recourse=1 if (inlist(lpstate, "CA", "MT", "NC") & inlist(purpose, "2", "3", "5"))	//code as recourse ALL refis in these states
	
	gen nonrecourse=(recourse==0)
	
	lab var recourse 		"Lender can seek judgment to recover the deficiency btwn outst mort and forecl revenue."
	lab var nonrecourse		"Recourse states defined by Ghent Kudlyak"
	
*ah)	Judicial States:
	gen judicial=1
	replace judicial=0 if (inlist (lpstate, "AL", "AK", "AR", "AS", "AZ", "CA", "DC", "GA", "HI") | ///
						   inlist (lpstate, "ID", "MI", "MN", "MS", "MO", "MT") | ///
						   inlist (lpstate, "NE", "NV", "NH", "OK", "OR", "RI") | ///
						   inlist (lpstate, "TN", "TX", "UT", "VA", "WA", "WV", "WY") | ///
						   inlist (lpstate, "CO", "NC"))
	lab var judicial	"Foreclosure requires judicial action."

*aj)	Optimal time until foreclosure
gen timeline=0
		replace timeline=74 if lpstate=="AL"  
		replace timeline=111 if lpstate=="AK"  
		replace timeline=115 if lpstate=="AZ"  
		replace timeline=90 if lpstate=="AR"  
		replace timeline=120 if lpstate=="CA"  
		replace timeline=173 if lpstate=="CO"  
		replace timeline=173 if lpstate=="CT"  
		replace timeline=300 if lpstate=="DE"  
		replace timeline=48 if lpstate=="DC"  
		replace timeline=150 if lpstate=="FL"  
		replace timeline=48 if lpstate=="GA"  
		replace timeline=320 if lpstate=="HI"   
		replace timeline=150 if lpstate=="ID"  
		replace timeline=345 if lpstate=="IL"  
		replace timeline=266 if lpstate=="IN"  
		replace timeline=180 if lpstate=="IA"  
		replace timeline=230 if lpstate=="KS"  
		replace timeline=198 if lpstate=="KY"  
		replace timeline=269 if lpstate=="LA"  
		replace timeline=270 if lpstate=="ME"  
		replace timeline=46 if lpstate=="MD"  
		replace timeline=75 if lpstate=="MA"  
		replace timeline=360 if lpstate=="MI"  
		replace timeline=280 if lpstate=="MN"  
		replace timeline=90 if lpstate=="MS"  
		replace timeline=65 if lpstate=="MO"  
		replace timeline=163 if lpstate=="MT"  
		replace timeline=176 if lpstate=="NE"  
		replace timeline=116 if lpstate=="NV"  
		replace timeline=75 if lpstate=="NH"  
		replace timeline=295 if lpstate=="NJ"  
		replace timeline=225 if lpstate=="NM"  
		replace timeline=445 if lpstate=="NY"  
		replace timeline=120 if lpstate=="NC"  
		replace timeline=150 if lpstate=="ND"  
		replace timeline=217 if lpstate=="OH"  
		replace timeline=201 if lpstate=="OK"  
		replace timeline=160 if lpstate=="OR"  
		replace timeline=300 if lpstate=="PA"  
		replace timeline=74 if lpstate=="RI"  
		replace timeline=180 if lpstate=="SC"  
		replace timeline=340 if lpstate=="SD"  
		replace timeline=55 if lpstate=="TN"  
		replace timeline=180 if lpstate=="TX"  
		replace timeline=139 if lpstate=="UT"  
		replace timeline=275 if lpstate=="VT"  
		replace timeline=60 if lpstate=="VA"  
		replace timeline=150 if lpstate=="WA"  
		replace timeline=120 if lpstate=="WV"  
		replace timeline=315 if lpstate=="WI"  
		replace timeline=180 if lpstate=="WY"  

*ak)	Mortgage Origination Year dummies. 
*	origin_date1 = "Origination date of Mort 1. LP"
*	STATA VARIABLE:   # of DAYS since Jan 1, 1960
		gen origin_yr=year(origin_date1)
		tab origin_yr, gen(origin_yr_dum)
		assert (origin_yr>=2002 & origin_yr<=2006)
	
*al)    Foreclosure Indicator Vars
		*cma_attr3904    str1   foreclosure w/in 24 months flag
		*cma_attr3905    str1   foreclosure flag
		
		rename cma_attr3904		foreclosure24
		rename cma_attr3905		foreclosure

****)	Label Variables
	lab var ccdebt_60dpd		"CC debt 60+ days past due."
	lab var ccdebt_60dpd_amt 	"Amt of CC debt 60+ days past due."
	lab var autodebt_60dpd		"Auto debt 60+ days past due."
	lab var autodebt_60dpd_amt 	"Amt of Auto debt 60+ days past due."
	lab var origin_date1		"Origination date of Mort 1. LP"
	lab var origin_yr		"Origination year of Mort 1. LP"
}
*


if 1==1 {	// gen more vars, drop unneeded vars
* Drop unneeded variables 
desc cust_attr27-cust_attr168
drop cust_attr27-cust_attr168						// drop 3+ mortgages
drop primary1-match158to1							// drop various indicators for primary mortage status and match to LP
drop matches1 anymatch1 x1 y1 temp1 lp1outstandingeq2-lp1outstandingeq158	// drop various other match indicators

egen id=group(cid)
sum id
sort id quarter 
xtset id quarter

* Define equity variables and delinquency transition variables, trim outliers - there is an LTV>800
gen pltv=homedebt/value1
sum pltv, detail
replace pltv=. if pltv > `r(p99)'
	*gen pltv2=pltv*pltv
	gen lpltv=l.pltv
	*gen lpltv2=l.pltv2
	*gen pltvuw=(pltv>1)
gen cltv=(homedebt+othermortgage)/value1
	sum cltv, detail
	replace cltv=. if (cltv > `r(p99)')
	*gen cltv2=cltv*cltv
	gen lcltv=l.cltv
	*gen lcltv2=l.cltv2
	*gen cltvuw=(cltv>1)

* Generate vars that define fraction of debt to all debt. Generate default indicators
gen homedebtshare=homedebt/alldebt						// primary mortgage debt as share of all debt
gen ccdebtshare=ccdebt/alldebt							// primary mortgage debt as share of all debt
gen autodebtshare=autodebt/alldebt						// primary mortgage debt as share of all debt
gen helocshare=helocs/alldebt							// primary mortgage debt as share of all debt
gen heloans=crtr_attr172
gen heloandebtshare=heloans/alldebt						// heloan debt as share of all debt

gen ccautoheloc=ccdebt+autodebt+helocs
gen ccauthohelocshare=ccautoheloc/alldebt					// cc auto and heloc debt as share of all debt
gen ccautoheloc_90dpd=((ccdebt_90dpd==1) | (autodebt_90dpd==1) | (helocs_90dpd==1)) // defaulted on cc, auto or heloc

gen cchelocshare=(ccdebt+helocs)/alldebt					// cc and heloc debt as share of all debt
gen ccheloc_90dpd=((ccdebt_90dpd==1) | (helocs_90dpd==1))   // defaulted on cc or heloc


* Generate vars that define fraction of debt to mortgage debt
gen heloc_homedebtshare = helocs/homedebt
gen cc_homedebtshare = ccdebt/homedebt
gen auto_homedebtshare = autodebt/homedebt
gen heloan_homedebtshare = heloans/homedebt
	
		lab var heloc_homedebtshare		"Heloc debt as share of primary mort debt."
		lab var cc_homedebtshare		"Credit Card debt as share of primary mort debt."
		lab var auto_homedebtshare		"Auto debt as share of primary mort debt."
		lab var heloan_homedebtshare	"Heloan debt as share of primary mort debt."

* Generate vars that define minimum credit card payment and min cc payment as a fraction of mortgage payment
	*cust_attr8   %7f    "payment first mortgage #1"		//loan level mortgage payments, not aggregated mort payments
	*crtr_attr160 %7f    "payment first mortgage"
	*cust_attr312 %7f    "first mortgage payment JMCS"		//aggregated mortgage payments
gen mortgage_payment = cust_attr8
gen cc_minpayment = .03*ccdebt
gen cc_mort_pymnt_rt = cc_minpayment/mortgage_payment	
*gen unusedcc_mortgage_p_ratio = unusedcc/mortgage_payment

	lab var cc_minpayment				"Min Payment Calc to be 3% of cc balance"
	lab var cc_mort_pymnt_rt 			"Ratio of cc_minpayment and mortgage_payment"
	*lab var unusedcc_mortgage_p_ratio	"Ratio of unused cc limit to mortgage payment"

	
* Location-Time Dummies
egen lpstate2=group(lpstate)							// LP State dummies
egen msa_yr=group(lpmsa EQy)							// MSA/year dummies
egen msa_q=group(lpmsa quarter)							// MSA/quarter dummies

* Fraction debt limit unused
*egen maxccdebt=rsum(crtr_attr180 crtr_attr181 crtr_attr185)	// cc credit limit. Take out other trades: crtr_attr187
gen maxccdebt=crtr_attr180
gen chng_maxccdebt=crtr_attr180 - l.crtr_attr180 if (crtr_attr180<. & l.crtr_attr180<.)

gen unusedcc=1-ccdebt/maxccdebt							// unused share of cc limit 
	replace unusedcc=0 if unusedcc==.
gen unusedheloc=1-helocs/crtr_attr184						// unused share of heloc limit
	replace unusedheloc=0 if unusedheloc==.
gen unusedccheloc = 1-(ccdebt+helocs)/(maxccdebt + crtr_attr184)		// unused share of cc + heloc limit 
	replace unusedccheloc=0 if unusedccheloc==.

* Change in hpi and change in prices
gen fhpi=(f.hpi-hpi)/hpi							// change in prices over next two quarters, assume forward looking
gen chghpi=(hpi-l.hpi)/hpi							// percentage change in HPI over previous 6 months

* Newly Delinquent Indicators
gen inmortgage_60dpd=(mortgage_60dpd==1 & l.mortgage_60dpd==0)			// newly 60dpd
gen inmortgage_90dpd=(mortgage_90dpd==1 & l.mortgage_90dpd==0)			// newly 90dpd

* Decile of lagged pltv
gen lpltvpct=1 if lpltv<0.8
replace lpltvpct=2 if lpltv>=0.8 & lpltv<0.9
replace lpltvpct=3 if lpltv>=0.9 & lpltv<1.0
replace lpltvpct=4 if lpltv>=1.0 & lpltv<1.1
replace lpltvpct=5 if lpltv>=1.1 & lpltv<1.2
replace lpltvpct=6 if lpltv>=1.2 & lpltv<.
tab lpltvpct, missing

* Decile of lagged cltv
gen lcltvpct=1 if lcltv<0.8
replace lcltvpct=2 if lcltv>=0.8 & lcltv<0.9
replace lcltvpct=3 if lcltv>=0.9 & lcltv<1.0
replace lcltvpct=4 if lcltv>=1.0 & lcltv<1.1
replace lcltvpct=5 if lcltv>=1.1 & lcltv<1.2
replace lcltvpct=6 if lcltv>=1.2 & lcltv<.
tab lcltvpct, missing

tab timeline, missing
gen timepct=1 if timeline<180
replace timepct=2 if timeline>=(180) & timeline<(365*3/4)
replace timepct=3 if timeline>=(365*3/4) & timeline<(365)
replace timepct=4 if timeline>=(365) & timeline<.

tab timepct, missing

* Decile of lagged pltv for Recourse and Default Status
gen nreclpltvpct = lpltvpct if recourse==0					// decile of lagged pltv if nonrecourse
	replace nreclpltvpct=0 if recourse==1 & lpltvpct~=.
gen reclpltvpct = lpltvpct if recourse==1					// decile of lagged pltv if recourse
	replace reclpltvpct=0 if recourse==0 & lpltvpct~=.
gen deflpltvpct = lpltvpct if mortgage_90dpd==1				// decile of lagged pltv if defaulted
	replace deflpltvpct=0 if mortgage_90dpd==0 & lpltvpct~=.
gen defnreclpltvpct = nreclpltvpct if mortgage_90dpd==1		// decile of lagged pltv if defaulted & nonrecourse
	replace defnreclpltvpct=0 if mortgage_90dpd==0 & nreclpltvpct~=.
gen deftimepct = timepct if mortgage_90dpd==1				// quintile of timeline if defaulted
	replace deftimepct=0 if mortgage_90dpd==0 & timepct~=.
	
* Decile of lagged cltv for Recourse and Default Status
gen nreclcltvpct = lcltvpct if recourse==0					// decile of lagged cltv if nonrecourse
	replace nreclcltvpct=0 if recourse==1 & lcltvpct~=.
gen reclcltvpct = lcltvpct if recourse==1					// decile of lagged cltv if recourse
	replace reclcltvpct=0 if recourse==0 & lcltvpct~=.
gen deflcltvpct = lcltvpct if mortgage_90dpd==1				// decile of lagged cltv if defaulted
	replace deflcltvpct=0 if mortgage_90dpd==0 & lcltvpct~=.
gen defnreclcltvpct = nreclcltvpct if mortgage_90dpd==1		// decile of lagged cltv if defaulted & nonrecourse
	replace defnreclcltvpct=0 if mortgage_90dpd==0 & nreclcltvpct~=.
	
* Change in debt amounts
sort id quarter 
foreach v in "helocs" "autodebt" "ccdebt" "ccautoheloc" "ccaccounts" "alldebt" "maxccdebt" {	// generate quarter difference variables
     gen d`v' = D1.`v' 
     lab var d`v' 	"Change in `v'."
}

* Indicators of debt increase
gen cc_incr1000= (ccdebt-l.ccdebt >=1000) if ccdebt<. & l.ccdebt<.		// indicators of ccdebt increase/decrease 
gen cc_decr1000= (ccdebt-l.ccdebt <=-1000) if ccdebt<. & l.ccdebt<.
*gen cc_incr1= (ccdebt-l.ccdebt >=1) if ccdebt<. & l.ccdebt<.	//just use dccdebt variable
*gen cc_decr1= (ccdebt-l.ccdebt <=-1) if ccdebt<. & l.ccdebt<.

gen maxccdebt_incr100=(maxccdebt-l.maxccdebt >=100) if maxccdebt<. & l.maxccdebt<.	//legitimate incr in ccdebt limit will incr by at least $100
gen maxccdebt_decr100=(maxccdebt-l.maxccdebt <=-100) if maxccdebt<. & l.maxccdebt<.

gen cc_incraccount= (ccaccounts-l.ccaccounts >=1) if ccaccounts<. & l.ccaccounts<.	// indicators of ccaccounts increase/decrease 
gen cc_decraccount= (ccaccounts-l.ccaccounts <=-1) if ccaccounts<. & l.ccaccounts<.
gen helocs_incr1000 = (helocs - l.helocs>=1000) if helocs<. & l.helocs<.	// indicators of heloc debt incr/decr
gen helocs_decr1000 = (helocs-l.helocs<=-10000) if helocs<. & l.helocs<.
gen new_auto_loan = dautodebt>10000 & dautodebt!=.				// indicator of new auto loan

	lab var cc_incr1000	"Indicator cc debt incr $1k or more"
	lab var cc_decr1000	"Indicator cc debt decr $1k or more"
	*lab var cc_incr1	"Indicator cc debt incr $1 or more"
	*lab var cc_decr1	"Indicator cc debt decr $1 or more"

* Generate lagged variables to be used in regs
local lagvars unusedcc unusedheloc cc_mort_pymnt_rt ccdebt_60dpd ccdebt_90dpd mortgage_90dpd dccaccounts
	foreach var of local lagvars {
		gen lag_`var' = l.`var'
		gen lag2_`var'= l2.`var'
		gen lag3_`var'= l3.`var'
		gen lag4_`var'= l4.`var'
		gen lag5_`var'= l5.`var'
		
		gen fwd_`var'   = f.`var'
		gen fwd2_`var'  = f2.`var'
		gen fwd3_`var'  = f3.`var'
		gen fwd4_`var'  = f4.`var'
		
		lab var lag_`var'	"`var' in prev qtr"
		lab var lag2_`var'	"`var' 2 qtrs ago"
		lab var lag3_`var'	"`var' 3 qtrs ago"
		
		lab var fwd_`var'		"`var' next qtr"
		lab var fwd2_`var'	"`var' 2 qtrs ahead"
		lab var fwd3_`var'	"`var' 3 qtrs ahead"
	}

* Unused cc limit can sometimes be negative (b/c cclimit<ccdebt). Bottom code it to zero.
	foreach var in unusedcc unusedheloc {
		replace lag_`var' = 0 if lag_`var'<0
		replace lag2_`var' = 0 if lag2_`var'<0
		replace lag3_`var' = 0 if lag3_`var'<0
	}
	
* Bankruptcy flag
capture rename cma_attr3903 bankrupt
	destring bankrupt, replace
	label var bankrupt 	"cma_attr3903 Eqfx Bankruptcy Flag"

* Account Openings and Closings
	*cma_attr3133	number accounts opened within 6 months
	*cma_attr3134	number revolving accounts opened within 6 months
	*cma_attr3135	number accounts opened within 12 months
	*cma_attr3136	number installment accounts opened within 6 months
	
	*cma_attr3137 	number open accounts
	*cma_attr3142 	number open installment accounts
	*cma_attr3146 	number open revolving accounts
	
	rename cma_attr3133 acctopen_past6
	rename cma_attr3134 revolveopen_past6
	rename cma_attr3135 acctopen_past12
	rename cma_attr3136 installopen_past6
	
	rename cma_attr3137 openaccts
	rename cma_attr3142 installopenaccts
	rename cma_attr3146 revolveopenaccts
	
	/* Generate var for number of accounts closed within past 6 months:
	   (Number open accounts at Q-2) + #Accts opened within past 6 mos - #Accts Closed with past 6 mos = #Open Accts at Q
	*/
	
	gen acctclosed_past6  = l2.openaccts + acctopen_past6 - openaccts
	gen acctclosed_past12 = l4.openaccts + acctopen_past12 - openaccts
	
	gen installclosed_past6 = l2.installopenaccts + installopen_past6 - installopenaccts
	gen revolveclosed_past6 = l2.revolveopenaccts + revolveopen_past6 - revolveopenaccts
	
	*Due to reporting methods to credit agency, possible to have a neg number of closings. Recode to 0 or missing here.
	foreach var in acctclosed_past6 acctclosed_past12 installclosed_past6 revolveclosed_past6 {
		tab `var', miss
		replace `var'=0 if inrange(`var',-10,-1)
		replace `var'=. if `var'<-10
		assert `var'>=0
	}
	
	lab var acctclosed_past6	"accounts closed within past 6 mos"
	lab var acctclosed_past12	"accounts closed within 12 months"
	lab var installclosed_past6	"number installment accounts opened within 6 months"
	lab var revolveclosed_past6	"number revolving accounts opened within 6 months"

*am)	Deficiency Judgment, Nonrecourse2, Judicial Review (Demiroglu Vars sent from Andrew)
gen defjudgement=1
	replace defjudgement=0   if (inlist(lpstate, "AK", "AZ", "MA", "MO", "MT") | inlist(lpstate, "ND", "WV", "CA"))
	replace defjudgement=0.5 if (inlist(lpstate, "NM", "WI")) 

gen nonrecourse2=defjudgement
	replace nonrecourse2=0 if defjudgement==1
	replace nonrecourse2=2 if defjudgement==0
	replace nonrecourse2=1 if defjudgement==0.5 //nonrecourse2:  factor variables may not contain noninteger values

gen judicialreview2=0
	replace judicialreview2=2 if inlist(lpstate, "CT", "DE", "HI", "LA", "RI")
	replace judicialreview2=1   if (inlist(lpstate, "FL", "IA", "IL", "IN", "KS") | inlist(lpstate, "KY", "MD", "ME", "NC", "ND") ///
								  | inlist(lpstate, "NJ", "NM", "NY", "OH", "PA") | inlist(lpstate, "SC", "VT", "WI"))

* Decile of lagged cltv for Recourse and Default Status
gen nrec2lcltvpct = lcltvpct if nonrecourse2==1		// decile of lagged cltv if nonrecourse
	replace nrec2lcltvpct=0 if nonrecourse2==0 & lcltvpct~=.

*- Label Demiroglu Vars
label define yesno_somewhat_lbl 0 "No" 1 "Yes" 2 "Somewhat"
label values defjudgement judicialreview2 yesno_somewhat_lbl
	lab var defjudgement		"Deficiency judgments allowed in state -Demiroglu Var"
	lab var nonrecourse2		"nonrecourse state -Demiroglu Var"
	lab var judicialreview2		"State has judicial foreclosure process -Demiroglu Var"
	lab var nrec2lcltvpct		"L.cltvpct if nonrecourse by Demiroglu defn; 0 if rec"
	

*an) Foreclosure Index Variable (Curtis paper sent from Andrew)
gen forecl_index=.
	replace forecl_index = 1.00 if inlist(lpstate, "ND", "WI")
	replace forecl_index = 1.67 if inlist(lpstate, "KS", "ME", "PA", "VT")
	replace forecl_index = 2.00 if inlist(lpstate, "IL", "IA", "LA")
	replace forecl_index = 2.33 if        lpstate=="MN"
	replace forecl_index = 2.67 if inlist(lpstate, "MI", "NJ", "NY", "OK", "SC")
	replace forecl_index = 3.00 if inlist(lpstate, "AL", "AZ", "CT", "DE", "FL", "HI", "IN", "KY") ///
								 | inlist(lpstate, "NM", "OH", "OR", "WY")
	replace forecl_index = 3.33 if inlist(lpstate, "AK", "CA", "MT", "WA")
	replace forecl_index = 3.67 if inlist(lpstate, "AR", "CO", "GA", "ID", "NE", "NV", "NC", "SD") ///
								 | inlist(lpstate, "TX", "UT")
	replace forecl_index = 4.00 if inlist(lpstate, "DC", "MD", "MA", "MS", "MO", "NH", "RI", "TN") ///
								 | inlist(lpstate, "VA", "WV")

	lab var forecl_index	"Foreclosure Index -Curtis Paper"

}

save "$andrewdata/data_for_regs_b4_timetoforecl.dta", replace	//previously used for analysis. Next add time to foreclosure var.


foreach time in year quarter {

	*Create REO vars in Equifax data so can merge on duration to REO data
  preserve
	gen REO_year=EQy
	gen REO_quarter = 1 if EQm==3
		replace REO_quarter=2 if EQm==6
		replace REO_quarter=3 if EQm==9
		replace REO_quarter=4 if EQm==12
	assert REO_quarter!=.
	gen county=1000*lpstatefips+lpcountyfips
	label var county	"1000*lpstatefips+lpcountyfips"

	if "`time'" == "year" 		local mergevars = "REO_year county"
	if "`time'" == "quarter"	local mergevars = "REO_year REO_quarter county"
	
	if "`time'" == "year"		local datalabel = "Equifax & LP data with time to forecl by county year."
	if "`time'" == "quarter"	local datalabel = "Equifax & LP data with time to forecl by county year quarter."
	
	*Merge in datafile with time to foreclosure var (Duration to REO measured by county year)
	noi disp ""
	noi disp ""
	noi disp "Merging on tempfile ``time'_duration_to_REO' to EQ data."
	merge m:1 `mergevars' using ``time'_duration_to_REO'	//destringed county var in this dataset
	drop if _merge==2
	drop _merge
	
	********************************************
	* Create bins for each percentile of duration to REO
	********************************************
	sort id quarter 
	xtset id quarter
	
	foreach num of numlist 5 10 25 40 50 {
	
	count if pctile_`num'==0
	replace pctile_`num'=. if pctile_`num'==999
	gen REO_cat_pctile_`num'=1 if (pctile_`num'>=0 & pctile_`num'<=3)
		replace REO_cat_pctile_`num'=2	if (pctile_`num'>3 & pctile_`num'<=6)
		replace REO_cat_pctile_`num'=3	if (pctile_`num'>6 & pctile_`num'<=9)
		replace REO_cat_pctile_`num'=4	if (pctile_`num'>9 & pctile_`num'<.)
		replace REO_cat_pctile_`num'=5	if (pctile_`num'==.)
	gen lagREO_cat_pctile_`num'=l.REO_cat_pctile_`num'			
	label define REO_cat_pctile_`num'_lbl  1 "0<=p`num'<=3" 2 "3<p`num'<=6" 3 "6<p`num'<=9" 4 "9<p`num'<." 5 "."
	label values REO_cat_pctile_`num' lagREO_cat_pctile_`num' REO_cat_pctile_`num'_lbl
	tab REO_cat_pctile_`num', miss
	tab lagREO_cat_pctile_`num', miss
	} // close numlist loop
	
	*--Save Final Data to use for Analysis - with Duration to REO measured by county year (or county quarter or county month)
	label data "`datalabel'"
	save "$andrewdata/EqLP_data_for_regs_`time'_REO_20.dta", replace
  restore
}

! echo "Done with 4-finaldataprep.do" | mail -s "Done with 4-finaldataprep.do" $email
log close
