set more off
capture log close
clear
set linesize 255
set pagesize 300
set varabbrev off
set matsize 11000
pause on

global andrew /san/Equifax/Work/equifax/samples/Andrew/HouseholdDebt/CreateData_and_Descriptives
global andrewdata $andrew/data
global logs $andrew/logs
global output $andrew/output/14-analysis_DynamicModels/QuarterlyREO/NoInAndOut_NoDelinqEntry
*global graphs $andrew/Graphs/10-analysis_DynamicModels/Intermediate_graphs
adopath + /san/Equifax/Work/equifax/samples/Andrew/ado
global email brandi.coates@ny.frb.org

log using $logs/14-analysis_DynamicMods_TTF_qtrly1NEWTRUNC_NDE.log, replace t	//use new truncation method	
// NDE = No Delinquent Entry

/************************************************************************************
* Last modified: June 12 2014 by Brandi Coates
* Same as 13-analysis_DynamicMods_TTF_qtrly1NEWTRUNC_NDE.do (drops those who enter the sample in mortgage delinquency)
* ---------- NON-interacted non-recourse and REO Specifications ------------------
	Replace these variables:
	0b.nonrecourse#1b.REO_cat_pctile_25
	0b.nonrecourse#2.REO_cat_pctile_25
	0b.nonrecourse#3.REO_cat_pctile_25
	0b.nonrecourse#4.REO_cat_pctile_25
	0b.nonrecourse#5.REO_cat_pctile_25
	1.nonrecourse#1b.REO_cat_pctile_25
	1.nonrecourse#2.REO_cat_pctile_25
	1.nonrecourse#3.REO_cat_pctile_25
	1.nonrecourse#4.REO_cat_pctile_25
	1.nonrecourse#5.REO_cat_pctile_25

	With:
	nonrecourse
	1b.REO_cat_pctile_25
	2.REO_cat_pctile_25
	3.REO_cat_pctile_25
	4.REO_cat_pctile_25
	5.REO_cat_pctile_25
************************************************************************************/


use "$andrewdata/EqLP_data_for_regs_quarter_REO_20.dta", clear

* Unused cc limit can sometimes be negative (b/c cclimit<ccdebt). Bottom code it to zero.
	replace unusedcc=0 if unusedcc<0
	replace unusedheloc=0 if unusedheloc<0
	
	replace lag_unusedcc=0 if lag_unusedcc<0
	replace lag_unusedheloc=0 if lag_unusedheloc<0
	
	*keep if lag_cc_mort_pymnt_rt < . & ccdebt_90dpd < . 
	
	capture rename cma_attr3903 bankrupt
	destring bankrupt, replace
	label var bankrupt 	"cma_attr3903 Eqfx Bankruptcy Flag"
	
	tab EQy bankrupt, miss
	
* DROP those who enter the sample in mortgage delinquency.
	by id: gen a=_n 	
	gen b=0
	replace b=1 if a==1 & mortgage_90dpd==1			//mark the first qtr defaulted
	by id: egen c=max(b)
	*list id quarter mortgage_90dpd a b c if inlist(id, 34, 560, 14982, 18820), sepby(id)
	
	count if a==1
	local CountBeforeDrop=`r(N)'
	drop if c==1
	count if a==1
	local CountAfterDrop=`r(N)'
	
	noi disp "There were `CountBeforeDrop' unique IDS before dropping those that go enter the sample in mort default, and `CountAfterDrop' afterward."
	qui count
	noi disp "There are now `r(N)' unique ID-quarter observations in the dataset."
	drop a b c

	
**** Use random 10% sample when troubleshooting code.
*gen random=runiform()
*keep if random<0.10
****

*****************************************************
*** SAMPLE RESTRICTIONS: CREATE DIFFERENT SAMPLES ***
*****************************************************

sort id quarter 

***--- SAMPLE 1---***
	preserve
	// keep only people that ever had cc debt
	by id: egen ccever=max(ccdebt)
		keep if ccever>0 & ccever<.		
		drop ccever
		
	// drop people that ever had student debt
	by id: egen sdever=max(studdebt)
		drop if sdever>0 & sdever<.		
		drop sdever

	// drop people that ever had OTHER debt		
	by id: egen odever=max(otherdebt)		// UNCOMMENT WHEN RESOLVE HOW TO DEFINE OTHER DEBT.
		drop if odever>0 & odever<.		
		drop odever
	list id EQy EQm mortgage_90dpd if id==220378, sepby(EQy)

	save $andrewdata/analysis_sample1_qtr.dta, replace
	restore

***--- SAMPLE 2---***
	preserve
	// keep only people that ever had heloan debt
	by id: egen heloanever=max(heloans)
		keep if heloanever>0 & heloanever<.		
		drop heloanever
		save $andrewdata/analysis_sample2_qtr.dta, replace
	restore

foreach sample of numlist 1/2 {
use  "$andrewdata/analysis_sample`sample'_qtr.dta", clear
sort id quarter 
xtset id quarter

*1. MAKE SURE THERE'S NOT TWO OR MORE MISSING CONSECUTIVE QUARTERS.  IF SO, DROP THE INDIVIDUAL.  WHAT FRACTION OF INDIVIDUALS (not Qs) DO WE LOSE?
noi disp "How many individuals do we lose if drop those with 2 or more  missing consecutive quarters?"
*tab quarter
codebook id	// # unique individs before drop those w/ 2 or more missing quarters
	sort id quarter
	by id: gen tag=quarter-quarter[_n-1]	//If no missing quarters should be 1.
	by id: gen first_qtr_id_appears =_n
	replace tag=0 if first_qtr_id_appears==1	//tag var always missing for first qtr since quarter[_n-1] undefined. Replace with 0.
	
	by id: egen dropthese=max(tag)
	drop if dropthese>=3	// Missing 2 or more consecutive quarters.
	drop tag first_qtr_id_appears dropthese
codebook id	// # unique individs AFTER drop those with 2 or more missing quarters


*-------->>>>>>> DROP those who DEFAULT then go CURRENT AGAIN <<<<<<<<<--------*
// drop if was in default and then go current again
*
by id: gen countthese=1 if _n==1
count if countthese==1
local beforeInandOut=`r(N)'

*gen inandout=(mortgage_90dpd==0 & (l.mortgage_90dpd==1 | l2.mortgage_90dpd==1 | l3.mortgage_90dpd==1 | l4.mortgage_90dpd==1))
gen inandout=(mortgage_90dpd==0 & (lag_mortgage_90dpd==1 | lag2_mortgage_90dpd==1 | lag3_mortgage_90dpd==1 | lag4_mortgage_90dpd==1))
by id: egen inandout_tag=max(inandout)
drop if inandout_tag==1

noi disp "Sample `sample': Double Check that no one goes in then out of bankruptcy."
egen mortseq=concat(lag2_mortgage_90dpd lag_mortgage_90dpd mortgage_90dpd fwd_mortgage_90dpd fwd2_mortgage_90dpd)
tab mortseq if inandout_tag==0
noi disp "A zero never proceeds a one, indicating that no one in the sample goes in then out of bankruptcy."

by id: gen alsocountthese=1 if _n==1
count if alsocountthese==1
local afterInandOut=`r(N)'

noi disp "There were `beforeInandOut' unique IDs before dropping those that go in & out or mort default, and `afterInandOut' afterward."
qui count
noi disp "There are now `r(N)' unique ID-quarter observations in the dataset."
drop countthese alsocountthese


*-------->>>>>>> Truncate 4 Qs afters initial default <<<<<<<<<--------*

/*
gen def4q=(mortgage_90dpd==1 & (lag_mortgage_90dpd==1 | lag_mortgage_90dpd==.) & (lag2_mortgage_90dpd==1 | lag2_mortgage_90dpd==.) ///
			     & (lag3_mortgage_90dpd==1 | lag3_mortgage_90dpd==.) & (lag4_mortgage_90dpd==1 | lag4_mortgage_90dpd==.) ///
			     & (lag5_mortgage_90dpd==1 | lag5_mortgage_90dpd==.)) // Could have l1=l2=l3=l4=1 and l5=. 

*by id: gen trunc=sum(def4q)	
*	drop if trunc>0		//trunc is greater than zero iff def4q is greater than zero, so sufficient to just drop if def4q > 0.
drop if def4q>0
*capture drop def4q trunc
*/

*------------------------------------------------------------------------------*
*---------------------- TRUNCATE USING NEW METHOD -----------------------------*
*------------------------------------------------------------------------------*
*Mark those who ever enter default
by id: egen defaulter = max(mortgage_90dpd) // max of nonmissing values, which are 0 and 1

*	
	by id: gen a=sum(mortgage_90dpd) 	//running total treats missing as zero in sum
	gen b=quarter if a==1			//mark the first qtr defaulted
	by id: egen firstdef=min(b)		//a var denoting 1st qtr default
	
	gen firstdef_4q=firstdef+4			//Four qtrs after first default
	drop if defaulter==1 & quarter>firstdef_4q 	//Truncate 4 Qs after initial default

*B/c we truncate 4Qs after initial default, f*.mortgage_90dpd should be missing for all *>=5
*Data is from 2002Q1 - 2011Q2, 38 quarters. Max * can be is 37
noi disp "--------->>>>>> DATA CHECK: ASSERTIONS TO CHECK DATA TRUNCATED PROPERLY <<<<-----"

	foreach num of numlist 5/37 {
	    *gen tag`num'=1 if f`num'.mortgage_90dpd!=. & mortgage_90dpd==1
	    *list id quarter mortgage_90dpd tag`num' if tag`num'==1, sepby(id)
	    qui count if f`num'.mortgage_90dpd!=. & mortgage_90dpd==1
	    noi disp ""
	    noi disp "`r(N)' obs violate assertion: f`num'.mortgage_90dpd==. if mortgage_90dpd==1"
	    *summarize f`num'.mortgage_90dpd if mortgage_90dpd==1
	    assert f`num'.mortgage_90dpd==. if mortgage_90dpd==1
	}

*list id EQy EQm mortgage_90dpd if id==22058, sepby(EQy)

noi disp "New code doesn't miss people if they're missing atmost one consecutive quarter. See the following 3 examples:"
noi disp ""
/* Compare with id==220378 AFTER truncation. Should only go up to 3/2008 since 6/2008 is missing.
. list id EQy EQm mortgage_90dpd if id==220378, sepby(EQy)

        +--------------------------------+
        |     id    EQy   EQm   mo~90dpd |
        |--------------------------------|
752261. | 220378   2006     3          0 |
752262. | 220378   2006     6          0 |
752263. | 220378   2006     9          0 |
752264. | 220378   2006    12          0 |
        |--------------------------------|
752265. | 220378   2007     3          0 |
752266. | 220378   2007     6          1 |
752267. | 220378   2007     9          1 |
752268. | 220378   2007    12          1 |
        |--------------------------------|
752269. | 220378   2008     3          1 |
752270. | 220378   2008     9          1 |
752271. | 220378   2008    12          1 |
        +--------------------------------+
*/
list id EQy EQm mortgage_90dpd if id==220378, sepby(EQy)
list id EQy EQm mortgage_90dpd if id==81259, sepby(EQy)
list id EQy EQm mortgage_90dpd if id==182531, sepby(EQy)

noi disp "Decide whether to keep restriction: keep if lag_cc_mort_pymnt_rt < . & ccdebt_90dpd < ."
keep if lag_cc_mort_pymnt_rt < . & ccdebt_90dpd < . // <<<------------------ decide whether to keep this restriction

noi disp "------------- Summary of Vars for Sample `sample' ----------*"
// summarize vars
sum dccaccounts cc_incraccount cc_decraccount dccdebt cc_incr1000 cc_decr1000 ccdebt_90dpd dhelocs helocs_incr1000 helocs_decr1000 helocs_90dpd dautodebt new_auto_loan autodebt_90dpd dalldebt fhpi chghpi lpltv lpltvpct nreclpltvpct deflpltvpct defnreclpltvpct  mortgage_90dpd timeline timepct deftimepct recourse unusedcc unusedheloc agecat risk_cat homedebtshare ccdebtshare autodebtshare helocshare if mortgage_90dpd==0
sum dccaccounts, detail
replace dccaccounts=. if (dccaccounts > `r(p99)' | dccaccounts < `r(p1)')	// some change by -40 or +38 cc in a quarter
sum dccdebt, detail
replace dccdebt=. if (dccdebt > `r(p99)' | dccdebt < `r(p1)')			// some multimillion dollar changes
sum dhelocs, detail
replace dhelocs=. if (dhelocs > `r(p99)' | dhelocs < `r(p1)')			// some multimillion dollar changes
sum dautodebt, detail
replace dautodebt=. if (dautodebt > `r(p99)' | dautodebt < `r(p1)')		// some multimillion dollar changes
sum dalldebt, detail
replace dalldebt=. if (dalldebt >`r(p99)' | dalldebt < `r(p1)')	
sum dccautoheloc, detail
replace dccautoheloc=. if (dccautoheloc > `r(p99)' | dccautoheloc < `r(p1)')		// some multimillion dollar changes
sum unusedcc, detail
replace unusedcc=. if (unusedcc < `r(p1)')					// some values less than 0

sum unusedheloc, detail
replace unusedheloc=. if (unusedheloc < `r(p1)' | unusedheloc > `r(p99)')	// some values less than 0
sum homedebtshare, detail
replace homedebtshare=. if (homedebtshare < `r(p1)' | homedebtshare > `r(p99)')			// some values greater than 0
sum heloandebtshare, detail
replace heloandebtshare=. if (heloandebtshare < `r(p1)' | heloandebtshare > `r(p99)')	

sum dccaccounts cc_incraccount cc_decraccount dccdebt cc_incr1000 cc_decr1000 ccdebt_90dpd cc_minpayment dhelocs helocs_incr1000 helocs_decr1000 helocs_90dpd dautodebt new_auto_loan autodebt_90dpd dalldebt dccautoheloc fhpi chghpi lpltv lpltvpct nreclpltvpct deflpltvpct defnreclpltvpct  mortgage_90dpd timeline timepct deftimepct recourse unusedcc unusedheloc agecat risk_cat homedebtshare ccdebtshare autodebtshare helocshare 

*gen byte nonrecourse=(recourse==0)

*Set helocs_90dpd, autodebt_90dpd to missing if no heloc, auto account
replace helocs_90dpd=. if helocs==0
replace autodebt_90dpd=. if autodebt==0

********************************************
* Summarize vars and save dataset
********************************************
sum ccdebt_90dpd helocs_90dpd autodebt_90dpd ccheloc_90dpd ccautoheloc_90dpd lpltv lpltvpct nreclpltvpct nonrecourse timeline timepct unusedcc unusedheloc unusedccheloc ccdebtshare autodebtshare helocshare cchelocshare ccauthohelocshare fhpi chghpi agecat risk_cat dccaccounts cc_incraccount cc_decraccount dccdebt cc_incr1000 cc_decr1000 dhelocs helocs_incr1000 helocs_decr1000 dautodebt new_auto_loan dalldebt dccautoheloc 
save  "$andrewdata/analysis_sample`sample'_final_20_qtr.dta", replace
capture erase "$andrewdata/analysis_sample`sample'_qtr.dta"
}



********************************************
*Delinquency transition models
********************************************

foreach ltv in /*pltv*/ cltv {
eststo clear
foreach num in 25 {
 foreach var in all low mid high{
 
*--The Regressions---*	
use "$andrewdata/analysis_sample1_final_20_qtr.dta", clear
	summarize pctile_`num'	//check that there's no 999 from the left censoring. These should've beeen replaced with missing values
	tab REO_cat_pctile_`num', miss
	*tab lagREO_cat_pctile_`num', miss	//don't lag in quarterly file -- already looking at duration to REO in prev 4 quarters
	
// Regs are run on diff subsets: all, ltv<90%, 90%<=ltv<=110%, ltv>110%
	if "`var'"=="all" {
		disp "Running on all obs."
	}

	else if "`var'"=="low" {
		keep if l`ltv'<.9
	}
	
	else if "`var'"=="mid" {
		keep if (l`ltv'>=0.9 & l`ltv'<1.1)
	}
	
	else {
		keep if l`ltv'>=1.1
	}

 foreach v in "mortgage_90dpd" {
 eststo `v'_`var': areg `v'  ib1.l`ltv'pct lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi nonrecourse ib1.REO_cat_pctile_25 ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 *eststo `v'_`var'2: areg `v' ib1.l`ltv'pct nonrecourse      lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi chghpi ib0.nonrecourse#ib1.lagREO_cat ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 }
 foreach v in "ccdebt_90dpd" {
 eststo `v'_`var': areg `v'  ib1.l`ltv'pct lag_cc_mort_pymnt_rt lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi nonrecourse ib1.REO_cat_pctile_25 ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 *eststo `v'_`var'2: areg `v' ib1.l`ltv'pct nonrecourse      lag_cc_mort_pymnt_rt lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi chghpi ib0.nonrecourse#ib1.lagREO_cat ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 }
 foreach v in "helocs_90dpd" {
 eststo `v'_`var': areg `v'  ib1.l`ltv'pct heloc_homedebtshare lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi nonrecourse ib1.REO_cat_pctile_25 ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 *eststo `v'_`var'2: areg `v' ib1.l`ltv'pct nonrecourse      heloc_homedebtshare lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi chghpi ib0.nonrecourse#ib1.lagREO_cat ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 }
 foreach v in "autodebt_90dpd" {
 eststo `v'_`var': areg `v'  ib1.l`ltv'pct auto_homedebtshare lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi nonrecourse ib1.REO_cat_pctile_25 ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 *eststo `v'_`var'2: areg `v' ib1.l`ltv'pct nonrecourse      auto_homedebtshare lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi chghpi ib0.nonrecourse#ib1.lagREO_cat ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 }
 foreach v in "dccaccounts" {
 eststo `v'_`var': areg `v'  ib1.l`ltv'pct lag_cc_mort_pymnt_rt lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi nonrecourse ib1.REO_cat_pctile_25 ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 *eststo `v'_`var'2: areg `v' ib1.l`ltv'pct nonrecourse      lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi chghpi ib0.nonrecourse#ib1.lagREO_cat ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 }
 foreach v in "bankrupt" {
 eststo `v'_`var': areg `v'  ib1.l`ltv'pct lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi nonrecourse ib1.REO_cat_pctile_25 ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 *eststo `v'_`var'2: areg `v' ib1.l`ltv'pct nonrecourse      lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi chghpi ib0.nonrecourse#ib1.lagREO_cat ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 }


*--- Heloans ---*
use "$andrewdata/analysis_sample2_final_20_qtr.dta", clear
	summarize pctile_`num'	//check that there's no 999 from the left censoring. These should've beeen replaced with missing values
	tab REO_cat_pctile_`num', miss
	*tab lagREO_cat_pctile_`num', miss
	
// Regs are run on diff subsets: all, ltv<90%, ltv>110%
	if "`var'"=="all" {
		disp "Running on all obs."
	}

	else if "`var'"=="low" {
		keep if l`ltv'<.9
	}
	
	else if "`var'"=="mid" {
		keep if (l`ltv'>=0.9 & l`ltv'<1.1)
	}
	
	else {
		keep if l`ltv'>=1.1
	}

 foreach v in "heloan_90dpd" {
 eststo `v'_`var': areg `v'  ib1.l`ltv'pct heloan_homedebtshare lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi nonrecourse ib1.REO_cat_pctile_25 ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 *eststo `v'_`var'2: areg `v' ib1.l`ltv'pct nonrecourse      heloan_homedebtshare lnlaghomedebt lag_unusedcc lag_unusedheloc fhpi chghpi ib0.nonrecourse#ib1.lagREO_cat ib1.agecat ib1.lrisk_cat origin_yr_dum*, absorb(msa_q) vce(robust)
 }


 } //close var loop

 
 ! echo "Dynamic Model `ltv' Regs done running for `num'th percentile." | mail -s "Progress: `num'th ptile Regs Done." $email
	
	esttab mortgage_90dpd_all mortgage_90dpd_low mortgage_90dpd_mid mortgage_90dpd_high ///
		ccdebt_90dpd_all ccdebt_90dpd_low ccdebt_90dpd_mid ccdebt_90dpd_high ///
		helocs_90dpd_all helocs_90dpd_low helocs_90dpd_mid helocs_90dpd_high ///
		autodebt_90dpd_all autodebt_90dpd_low autodebt_90dpd_mid autodebt_90dpd_high ///
		dccaccounts_all dccaccounts_low dccaccounts_mid dccaccounts_high ///
		heloan_90dpd_all heloan_90dpd_low heloan_90dpd_mid heloan_90dpd_high ///
		bankrupt_all bankrupt_low bankrupt_mid bankrupt_high ///
		///
		/*mortgage_90dpd_all2 mortgage_90dpd_low2 mortgage_90dpd_mid2 mortgage_90dpd_high2 ///
		ccdebt_90dpd_all2 ccdebt_90dpd_low2 ccdebt_90dpd_mid2 ccdebt_90dpd_high2 ///
		helocs_90dpd_all2 helocs_90dpd_low2 helocs_90dpd_mid2 helocs_90dpd_high2 ///
		autodebt_90dpd_all2 autodebt_90dpd_low2 autodebt_90dpd_mid2 autodebt_90dpd_high2 ///
		heloan_90dpd_all2 heloan_90dpd_low2 heloan_90dpd_mid2 heloan_90dpd_high2 ///
		bankrupt_all2 bankrupt_low2 bankrupt_mid2 bankrupt_high2 */ ///
		///
		using "$output/14-regs_DM_`ltv'_p`num'_qtrly1NEWTRUNC_NDE.csv", ar2 title(`num'th Percentile of Duration to REO binned by cnty-yr) staraux replace ///
		  nonumbers mtitles("Mortg_All" "Low" "Mid" "High" "CCdebt_All" "Low" "Mid" "High" "Heloc_All" "Low" "Mid" "High" "Auto_All" "Low" "Mid" "High" "CCNumber_All" "Low" "Mid" "High" "Heloan_All" "Low" "Mid" "High" "Bkrpt_All" "Low" "Mid" "High") ///	  
	

 } //close num loop   
} //close ltv loop


! echo "Dynamic Model `ltv' Regs done running." | mail -s "Progress: Regs All Done." $email
capture log close
